@@ -1,5 +1,6 @@
 from ZTUtils import make_query
 
+import time
 from zope.interface import implements
 from zope.interface import providedBy
 from Products.ATContentTypes.interface import IATTopic
@@ -31,6 +32,7 @@ except ImportException:
     LEADIMAGE_EXISTS = False
     
 
+_N_CHAR = 100
 
 DEFAULT_ALLOWED_TYPES = (
     'News Item',
@@ -165,6 +167,9 @@ class Renderer(base.Renderer):
             return True
         return False
 
+    def currenttime(self):
+        return time.time()
+
     @property
     def prefs(self):
         res = ''
@@ -196,6 +201,14 @@ class Renderer(base.Renderer):
             req_items['portal_type'] = list(self.data.allowed_types)
         return '%s/search?%s' % (portal_url, make_query(req_items))
 
+    def trimDescription(self, desc):
+        if len(desc) > _N_CHAR:
+                res = desc[0:_N_CHAR]
+                lastspace = res.rfind(" ")
+                res = res[0:lastspace] + " ..."
+                return res
+        else:
+                return desc
     
     def _contents(self):
         contents = []
